@@ -1,5 +1,3 @@
-import re
-
 import numpy as np
 import pytest
 from conntility import ConnectivityMatrix
@@ -68,7 +66,7 @@ def test_connectivity_matrix_extraction(tmp_path):
     )
     grid_scan.execute()
 
-    with pytest.raises(ValueError, match=re.escape("Unknown properties: [np.str_('INVALID')]")):
+    with pytest.raises(ValueError, match=r"Unknown properties:.*INVALID"):
         obi.run_tasks_for_generated_scan(grid_scan)
 
     # (c) Matrix extraction from two circuits through grid scan
